# -*- coding: utf-8 -*-
import importlib
import libflavour
from strictyaml import load
from pathlib import Path

def settings(config):
    pass
    # load all the other flavour enabled settings
    # read flavour.yml
    # get the addons
    addons = ["django_cloud_essentials"]

    with Path("flavour.yml").open("r") as yaml:
        yaml_data = load(yaml.read(), libflavour.schema.schema_project)

    for addon in yaml_data["addons"]:
        try:
            a = importlib.import_module(str(yaml_data["addons"][addon]["settings"]["packagename"]))
            a.settings(config)
        except Exception as e:
            print(e)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from django_flavour import __version__

PACKAGE = "django-flavour"

setup(
    name=PACKAGE,
    version=__version__,
    description="Adds flavour support for other django addons",
    author="Divio AG",
    author_email="info@divio.ch",
    url="https://www.divio.com",
    packages=find_packages(),
    package_dir={PACKAGE: PACKAGE},
    package_data={PACKAGE: ['addon.yml']},
    install_requires=("Django", "django-getenv", "libflavour", "strictyaml"),
    include_package_data=True,
    zip_safe=False,
)
